@@ -48,17 +48,17 @@ public class StringrefTest extends CBORTestBase
 
         assertToken(JsonToken.START_OBJECT, parser.nextToken());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        String rankStr = parser.getCurrentName();
+        String rankStr = parser.currentName();
         assertEquals("rank", rankStr);
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(4, parser.getValueAsInt());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        String countStr = parser.getCurrentName();
+        String countStr = parser.currentName();
         assertEquals("count", countStr);
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(417, parser.getValueAsInt());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        String nameStr = parser.getCurrentName();
+        String nameStr = parser.currentName();
         assertEquals("name", nameStr);
         assertToken(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("Cocktail", parser.getText());
@@ -66,30 +66,30 @@ public class StringrefTest extends CBORTestBase
 
         assertToken(JsonToken.START_OBJECT, parser.nextToken());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        assertSame(nameStr, parser.getCurrentName());
+        assertSame(nameStr, parser.currentName());
         assertToken(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("Bath", parser.getText());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        assertSame(countStr, parser.getCurrentName());
+        assertSame(countStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(312, parser.getValueAsInt());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        assertSame(rankStr, parser.getCurrentName());
+        assertSame(rankStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(4, parser.getValueAsInt());
         assertToken(JsonToken.END_OBJECT, parser.nextToken());
 
         assertToken(JsonToken.START_OBJECT, parser.nextToken());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        assertSame(nameStr, parser.getCurrentName());
+        assertSame(nameStr, parser.currentName());
         assertToken(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("Food", parser.getText());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        assertSame(countStr, parser.getCurrentName());
+        assertSame(countStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(691, parser.getValueAsInt());
         assertToken(JsonToken.FIELD_NAME, parser.nextToken());
-        assertSame(rankStr, parser.getCurrentName());
+        assertSame(rankStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(4, parser.getValueAsInt());
         assertToken(JsonToken.END_OBJECT, parser.nextToken());
@@ -138,17 +138,17 @@ public class StringrefTest extends CBORTestBase
 
         assertToken(JsonToken.START_OBJECT, parser.nextToken());
         assertTrue(parser.nextFieldName(new SerializedString("rank")));
-        String rankStr = parser.getCurrentName();
+        String rankStr = parser.currentName();
         assertEquals("rank", rankStr);
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(4, parser.getValueAsInt());
         assertTrue(parser.nextFieldName(new SerializedString("count")));
-        String countStr = parser.getCurrentName();
+        String countStr = parser.currentName();
         assertEquals("count", countStr);
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(417, parser.getValueAsInt());
         assertTrue(parser.nextFieldName(new SerializedString("name")));
-        String nameStr = parser.getCurrentName();
+        String nameStr = parser.currentName();
         assertEquals("name", nameStr);
         assertToken(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("Cocktail", parser.getText());
@@ -156,30 +156,30 @@ public class StringrefTest extends CBORTestBase
 
         assertToken(JsonToken.START_OBJECT, parser.nextToken());
         assertTrue(parser.nextFieldName(new SerializedString("name")));
-        assertSame(nameStr, parser.getCurrentName());
+        assertSame(nameStr, parser.currentName());
         assertToken(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("Bath", parser.getText());
         assertTrue(parser.nextFieldName(new SerializedString("count")));
-        assertSame(countStr, parser.getCurrentName());
+        assertSame(countStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(312, parser.getValueAsInt());
         assertTrue(parser.nextFieldName(new SerializedString("rank")));
-        assertSame(rankStr, parser.getCurrentName());
+        assertSame(rankStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(4, parser.getValueAsInt());
         assertToken(JsonToken.END_OBJECT, parser.nextToken());
 
         assertToken(JsonToken.START_OBJECT, parser.nextToken());
         assertTrue(parser.nextFieldName(new SerializedString("name")));
-        assertSame(nameStr, parser.getCurrentName());
+        assertSame(nameStr, parser.currentName());
         assertToken(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("Food", parser.getText());
         assertTrue(parser.nextFieldName(new SerializedString("count")));
-        assertSame(countStr, parser.getCurrentName());
+        assertSame(countStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(691, parser.getValueAsInt());
         assertTrue(parser.nextFieldName(new SerializedString("rank")));
-        assertSame(rankStr, parser.getCurrentName());
+        assertSame(rankStr, parser.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, parser.nextToken());
         assertEquals(4, parser.getValueAsInt());
         assertToken(JsonToken.END_OBJECT, parser.nextToken());
