@@ -269,14 +269,12 @@ public class IonParser
          if (_currToken != null) { // null only before/after document
             switch (_currToken) {
             case FIELD_NAME:
-                return getCurrentName();
+                return currentName();
             case VALUE_STRING:
                 try {
-                    // stringValue() will throw an UnknownSymbolException if we're
-                    // trying to get the text for a symbol id that cannot be resolved.
                     return _reader.stringValue();
-                } catch (UnknownSymbolException e) {
-                    throw _constructError(e.getMessage(), e);
+                } catch (IonException e) {
+                    return _reportCorruptContent(e);
                 }
             case VALUE_NUMBER_INT:
             case VALUE_NUMBER_FLOAT:
@@ -285,8 +283,10 @@ public class IonParser
             // Some special cases here:
             case VALUE_EMBEDDED_OBJECT:
                 if (_reader.getType() == IonType.TIMESTAMP) {
-                    Timestamp ts = _reader.timestampValue();
-                    if (ts != null) return ts.toString();
+                    Timestamp ts = _timestampFromIonReader();
+                    if (ts != null) {
+                        return ts.toString();
+                    }
                 }
                 // How about CLOB?
                 break;
@@ -305,7 +305,8 @@ public class IonParser
 
     @Override
     public int getTextLength() throws IOException {
-        return getText().length();
+        String str = getText();
+        return (str == null) ? 0 : str.length();
     }
 
     @Override
@@ -321,80 +322,207 @@ public class IonParser
 
     @Override
     public BigInteger getBigIntegerValue() throws IOException {
-        return _reader.bigIntegerValue();
+        _verifyIsNumberToken();
+        return _getBigIntegerValue();
+    }
+
+    // @since 2.17
+    private BigInteger _getBigIntegerValue() throws IOException {
+        try {
+            return _reader.bigIntegerValue();
+        } catch (IonException e) {
+            return _reportCorruptNumber(e);
+        }
     }
 
     @Override
     public BigDecimal getDecimalValue() throws IOException {
-        return _reader.bigDecimalValue();
+
+        _verifyIsNumberToken();
+        return _getBigDecimalValue();
+    }
+
+    // @since 2.17
+    private BigDecimal _getBigDecimalValue() throws IOException {
+        try {
+            return _reader.bigDecimalValue();
+        } catch (IonException e) {
+            return _reportCorruptNumber(e);
+        }
     }
 
     @Override
     public double getDoubleValue() throws IOException {
-        return _reader.doubleValue();
+        _verifyIsNumberToken();
+        return _getDoubleValue();
+    }
+
+    // @since 2.17
+    private double _getDoubleValue() throws IOException {
+        try {
+            return _reader.doubleValue();
+        } catch (IonException e) {
+            return _reportCorruptNumber(e);
+        }
     }
 
     @Override
     public float getFloatValue() throws IOException {
-        return (float) _reader.doubleValue();
+        _verifyIsNumberToken();
+        // 04-May-2024, tatu: May seem odd but Ion really does not
+        //   expose 32-bit floats even if it MAY use them internally
+        //   for encoding. So:
+        return (float) _getDoubleValue();
     }
 
     @Override
     public int getIntValue() throws IOException {
-        return _reader.intValue();
+        _verifyIsNumberToken();
+        return _getIntValue();
+    }
+
+    // @since 2.17
+    private int _getIntValue() throws IOException {
+        try {
+            NumberType numberType = getNumberType();
+            if (numberType == NumberType.LONG) {
+                int result = _reader.intValue();
+                if ((long) result != _reader.longValue()) {
+                    this.reportOverflowInt();
+                }
+                return result;
+            }
+            if (numberType == NumberType.BIG_INTEGER) {
+                BigInteger bigInteger = _reader.bigIntegerValue();
+                if (BI_MIN_INT.compareTo(bigInteger) > 0 || BI_MAX_INT.compareTo(bigInteger) < 0) {
+                    this.reportOverflowInt();
+                }
+                return bigInteger.intValue();
+            } else {
+                return _reader.intValue();
+            }
+        } catch (IonException e) {
+            return _reportCorruptNumber(e);
+        }
     }
 
     @Override
     public long getLongValue() throws IOException {
-        return _reader.longValue();
+        _verifyIsNumberToken();
+        return _getLongValue();
+    }
+
+    // @since 2.17
+    private long _getLongValue() throws IOException {
+        try {
+            if (this.getNumberType() == NumberType.BIG_INTEGER) {
+                BigInteger bigInteger = _reader.bigIntegerValue();
+                if (BI_MIN_INT.compareTo(bigInteger) > 0 || BI_MAX_INT.compareTo(bigInteger) < 0) {
+                    this.reportOverflowLong();
+                }
+                return bigInteger.longValue();
+            } else {
+                return _reader.longValue();
+            }
+        } catch (IonException e) {
+            return _reportCorruptNumber(e);
+        }
+    }
+    
+    // @since 2.17
+    private void _verifyIsNumberToken() throws IOException
+    {
+        if (_currToken != JsonToken.VALUE_NUMBER_INT && _currToken != JsonToken.VALUE_NUMBER_FLOAT) {
+            // Same as `ParserBase._parseNumericValue()` exception:
+            _reportError("Current token (%s) not numeric, can not use numeric value accessors",
+                    _currToken);
+        }
     }
 
     @Override
     public NumberType getNumberType() throws IOException
     {
-        IonType type = _reader.getType();
-        if (type != null) {
-            // Hmmh. Looks like Ion gives little bit looser definition here;
-            // harder to pin down exact type. But let's try some checks still.
-            switch (type) {
-            case DECIMAL:
-                //Ion decimals can be arbitrary precision, need to read as big decimal
-                return NumberType.BIG_DECIMAL;
-            case INT:
-                IntegerSize size = _reader.getIntegerSize();
-                switch (size) {
+        if (_currToken == JsonToken.VALUE_NUMBER_INT
+                || _currToken == JsonToken.VALUE_NUMBER_FLOAT
+                // 30-Dec-2023, tatu: This is odd, but some current tests seem to
+                //    expect this case to work when creating `IonParser` from `IonReader`,
+                //    which does not seem to work without work-around like this:
+                || ((_currToken == null) && !isClosed())) {
+            IonType type = _reader.getType();
+            if (type != null) {
+                // Hmmh. Looks like Ion gives little bit looser definition here;
+                // harder to pin down exact type. But let's try some checks still.
+                switch (type) {
+                case DECIMAL:
+                    //Ion decimals can be arbitrary precision, need to read as big decimal
+                    return NumberType.BIG_DECIMAL;
                 case INT:
-                    return NumberType.INT;
-                case LONG:
-                    return NumberType.LONG;
+                    final IntegerSize size;
+                    try {
+                        size = _reader.getIntegerSize();
+                    } catch (IonException e) {
+                        return _reportCorruptNumber(e);
+                    }
+                    if (size == null) {
+                        _reportError("Current token (%s) not integer", _currToken);
+                    }
+                    switch (size) {
+                    case INT:
+                        return NumberType.INT;
+                    case LONG:
+                        return NumberType.LONG;
+                    default:
+                        return NumberType.BIG_INTEGER;
+                    }
+                case FLOAT:
+                    // 04-May-2024, tatu: Ion really does not expose 32-bit floats, so:
+                    return NumberType.DOUBLE;
                 default:
-                    return NumberType.BIG_INTEGER;
                 }
-            case FLOAT:
-                return NumberType.DOUBLE;
-            default:
             }
         }
         return null;
     }
 
+    @Override // since 2.17
+    public NumberTypeFP getNumberTypeFP() throws IOException
+    {
+        if (_currToken == JsonToken.VALUE_NUMBER_FLOAT) {
+            final IonType type = _reader.getType();
+            if (type == IonType.FLOAT) {
+                // 06-Jan-2024, tatu: Existing code maps Ion `FLOAT` into Java
+                //    `float`. But code in `IonReader` suggests `Double` might
+                //    be more accurate mapping... odd.
+                // 04-May-2024, tatu: Ion really does not expose 32-bit floats;
+                //    must expose as 64-bit here too
+                return NumberTypeFP.DOUBLE64;
+            }
+            if (type == IonType.DECIMAL) {
+                // 06-Jan-2024, tatu: Seems like `DECIMAL` is expected to map
+                //    to `BigDecimal`, as per existing code so:
+                return NumberTypeFP.BIG_DECIMAL;
+            }
+        }
+        return NumberTypeFP.UNKNOWN;
+    }
+
     @Override
     public Number getNumberValue() throws IOException {
         NumberType nt = getNumberType();
         if (nt != null) {
             switch (nt) {
             case INT:
-                return _reader.intValue();
+                return _getIntValue();
             case LONG:
-                return _reader.longValue();
+                return _getLongValue();
             case FLOAT:
-                return (float) _reader.doubleValue();
+                return (float) _getDoubleValue();
             case DOUBLE:
-                return _reader.doubleValue();
+                return _getDoubleValue();
             case BIG_DECIMAL:
-                return _reader.bigDecimalValue();
+                return _getBigDecimalValue();
             case BIG_INTEGER:
-                return getBigIntegerValue();
+                return _getBigIntegerValue();
             }
         }
         return null;
@@ -418,7 +546,7 @@ public class IonParser
             switch (_reader.getType()) {
             case BLOB:
             case CLOB: // looks like CLOBs are much like BLOBs...
-                return _reader.newBytes();
+                return _bytesFromIonReader();
             default:
             }
         }
@@ -446,16 +574,10 @@ public class IonParser
         if (_currToken == JsonToken.VALUE_EMBEDDED_OBJECT) {
             switch (_reader.getType()) {
             case TIMESTAMP:
-                try {
-                    return _reader.timestampValue();
-                } catch (IllegalArgumentException e) {
-                    throw _constructError(String.format(
-                            "Invalid embedded TIMESTAMP value, problem: %s", e.getMessage()),
-                            e);
-                }
+                return _timestampFromIonReader();
             case BLOB:
             case CLOB:
-                return _reader.newBytes();
+                return _bytesFromIonReader();
             // What about CLOB?
             default:
             }
@@ -463,6 +585,22 @@ public class IonParser
         return getIonValue();
     }
 
+    // @since 2.17
+    private byte[] _bytesFromIonReader() throws IOException {
+        return _reader.newBytes();
+    }
+
+    // @since 2.17
+    private Timestamp _timestampFromIonReader() throws IOException {
+        try {
+            return _reader.timestampValue();
+        } catch (IllegalArgumentException e) {
+            throw _constructError(String.format(
+                    "Invalid embedded TIMESTAMP value, problem: %s", e.getMessage()),
+                    e);
+        }
+    }
+
     /*
     /**********************************************************
     /* Public API, Native Ids (type, object)
@@ -487,26 +625,37 @@ public class IonParser
      */
 
     @Override
-    public JsonLocation getCurrentLocation() {
+    public JsonLocation currentLocation() {
         return JsonLocation.NA;
     }
 
     @Override
-    public String getCurrentName() throws IOException {
+    public JsonLocation currentTokenLocation() {
+        return JsonLocation.NA;
+    }
+
+    @Deprecated // since 2.17
+    @Override
+    public JsonLocation getCurrentLocation() { return currentLocation(); }
+
+    @Deprecated // since 2.17
+    @Override
+    public JsonLocation getTokenLocation() { return currentTokenLocation(); }
+
+    @Override
+    public String currentName() throws IOException {
         return _parsingContext.getCurrentName();
     }
 
+    @Deprecated // since 2.17
+    @Override
+    public String getCurrentName() throws IOException { return currentName(); }
+    
     @Override
     public JsonStreamContext getParsingContext() {
         return _parsingContext;
     }
 
-
-    @Override
-    public JsonLocation getTokenLocation() {
-        return JsonLocation.NA;
-    }
-
     @Override
     public JsonToken nextToken() throws IOException
     {
@@ -528,11 +677,11 @@ public class IonParser
         try {
             type = _reader.next();
         } catch (IonException e) {
-            _wrapError(e.getMessage(), e);
+            return _reportCorruptContent(e);
+
         }
         if (type == null) {
             if (_parsingContext.inRoot()) { // EOF?
-                close();
                 _currToken = null;
             } else {
                 _parsingContext = _parsingContext.getParent();
@@ -545,13 +694,15 @@ public class IonParser
         boolean inStruct = !_parsingContext.inRoot() && _reader.isInStruct();
         // (isInStruct can return true for the first value read if the reader
         // was created from an IonValue that has a parent container)
+        final String name;
         try {
             // getFieldName() can throw an UnknownSymbolException if the text of the
             // field name symbol cannot be resolved.
-            _parsingContext.setCurrentName(inStruct ? _reader.getFieldName() : null);
-        } catch (UnknownSymbolException e) {
-            _wrapError(e.getMessage(), e);
+            name = inStruct ? _reader.getFieldName() : null;
+        } catch (IonException e) {
+            return _reportCorruptContent(e);
         }
+        _parsingContext.setCurrentName(name);
         JsonToken t = _tokenFromType(type);
         // and return either field name first
         if (inStruct) {
@@ -614,7 +765,7 @@ public class IonParser
      *****************************************************************
      * Internal helper methods
      *****************************************************************
-      */
+     */
 
     protected JsonToken _tokenFromType(IonType type)
     {
@@ -665,6 +816,28 @@ public class IonParser
         }
     }
 
+    private <T> T _reportCorruptContent(Throwable e) throws IOException
+    {
+        String origMsg = e.getMessage();
+        if (origMsg == null) {
+            origMsg = "[no exception message]";
+        }
+        final String msg = String.format("Corrupt content to decode; underlying `IonReader` problem: (%s) %s",
+                e.getClass().getName(), origMsg);
+        throw _constructError(msg, e);
+    }
+
+    private <T> T _reportCorruptNumber(Throwable e) throws IOException
+    {
+        String origMsg = e.getMessage();
+        if (origMsg == null) {
+            origMsg = "[no exception message]";
+        }
+        final String msg = String.format("Corrupt Number value to decode; underlying `IonReader` problem: (%s) %s",
+                e.getClass().getName(), origMsg);
+        throw _constructError(msg, e);
+    }
+
     @Override
     public void overrideCurrentName(String name) {
         try {
