@@ -12,6 +12,7 @@ import com.fasterxml.jackson.core.util.ByteArrayBuilder;
 import com.fasterxml.jackson.core.util.JacksonFeatureSet;
 import com.fasterxml.jackson.core.util.TextBuffer;
 import com.fasterxml.jackson.core.util.VersionUtil;
+
 import com.fasterxml.jackson.dataformat.protobuf.schema.*;
 
 public class ProtobufParser extends ParserMinimalBase
@@ -385,20 +386,7 @@ public class ProtobufParser extends ParserMinimalBase
      * but we do have byte offset to specify.
      */
     @Override
-    public JsonLocation getTokenLocation()
-    {
-        // token location is correctly managed...
-        return new JsonLocation(_ioContext.contentReference(),
-                _tokenInputTotal, // bytes
-                -1, -1, (int) _tokenInputTotal); // char offset, line, column
-    }
-
-    /**
-     * Overridden since we do not really have character-based locations,
-     * but we do have byte offset to specify.
-     */
-    @Override
-    public JsonLocation getCurrentLocation()
+    public JsonLocation currentLocation()
     {
         final long offset = _currInputProcessed + _inputPtr;
         return new JsonLocation(_ioContext.contentReference(),
@@ -406,20 +394,49 @@ public class ProtobufParser extends ParserMinimalBase
                 -1, -1, (int) offset); // char offset, line, column
     }
 
+    /**
+     * Overridden since we do not really have character-based locations,
+     * but we do have byte offset to specify.
+     */
+    @Override
+    public JsonLocation currentTokenLocation()
+    {
+        // token location is correctly managed...
+        return new JsonLocation(_ioContext.contentReference(),
+                _tokenInputTotal, // bytes
+                -1, -1, (int) _tokenInputTotal); // char offset, line, column
+    }
+
+    @Deprecated // since 2.17
+    @Override
+    public JsonLocation getCurrentLocation() { return currentLocation(); }
+
+    @Deprecated // since 2.17
+    @Override
+    public JsonLocation getTokenLocation() { return currentTokenLocation(); }
+
     /**
      * Method that can be called to get the name associated with
      * the current event.
      */
-    @Override
-    public String getCurrentName() throws IOException
+    @Override // since 2.17
+    public String currentName() throws IOException
     {
         if (_currToken == JsonToken.START_OBJECT || _currToken == JsonToken.START_ARRAY) {
             ProtobufReadContext parent = _parsingContext.getParent();
+            if (parent == null) { // For root level
+                // jackson-core `ParserBase` just falls through to current but we won't?
+                return null;
+            }
             return parent.getCurrentName();
         }
         return _parsingContext.getCurrentName();
     }
 
+    @Deprecated // since 2.17
+    @Override
+    public String getCurrentName() throws IOException { return currentName(); }
+
     @Override
     public void overrideCurrentName(String name)
     {
@@ -427,6 +444,9 @@ public class ProtobufParser extends ParserMinimalBase
         ProtobufReadContext ctxt = _parsingContext;
         if (_currToken == JsonToken.START_OBJECT || _currToken == JsonToken.START_ARRAY) {
             ctxt = ctxt.getParent();
+            if (ctxt == null) { // should we error out or... ?
+                return;
+            }
         }
         ctxt.setCurrentName(name);
     }
@@ -445,6 +465,11 @@ public class ProtobufParser extends ParserMinimalBase
                 _releaseBuffers();
             }
             _ioContext.close();
+            // 17-Jan-2024, tatu: Most code paths won't update context so:
+            if (!_parsingContext.inRoot()) {
+                _parsingContext = _parsingContext.getParent();
+            }
+            _parsingContext.setCurrentName(null);
         }
     }
 
@@ -578,7 +603,7 @@ public class ProtobufParser extends ParserMinimalBase
                 return t;
             }
         case STATE_NESTED_KEY:
-            if (_checkEnd()) {
+            if (_checkEnd()) { // will update _parsingContext
                 return (_currToken = JsonToken.END_OBJECT);
             }
             return _handleNestedKey(_decodeVInt());
@@ -947,7 +972,7 @@ public class ProtobufParser extends ParserMinimalBase
             _skipUnknownValue(wireType);
             // 05-Dec-2017, tatu: as per [#126] seems like we need to check this not just for
             //    STATE_NESTED_KEY but for arrays too at least?
-            if (_checkEnd()) {
+            if (_checkEnd()) { // updates _parsingContext
                 return (_currToken = JsonToken.END_OBJECT);
             }
             if (_state == STATE_NESTED_KEY) {
@@ -1049,7 +1074,7 @@ public class ProtobufParser extends ParserMinimalBase
             return name.equals(sstr.getValue());
         }
         if (_state == STATE_NESTED_KEY) {
-            if (_checkEnd()) {
+            if (_checkEnd()) { // updates _parsingContext
                 _currToken = JsonToken.END_OBJECT;
                 return false;
             }
@@ -1133,7 +1158,7 @@ public class ProtobufParser extends ParserMinimalBase
             return name;
         }
         if (_state == STATE_NESTED_KEY) {
-            if (_checkEnd()) {
+            if (_checkEnd()) { // updates _parsingContext
                 _currToken = JsonToken.END_OBJECT;
                 return null;
             }
@@ -1361,13 +1386,15 @@ public class ProtobufParser extends ParserMinimalBase
                 return _textBuffer.size();
             case FIELD_NAME:
                 return _parsingContext.getCurrentName().length();
-                // fall through
             case VALUE_NUMBER_INT:
             case VALUE_NUMBER_FLOAT:
                 return getNumberValue().toString().length();
-
             default:
-                return _currToken.asCharArray().length;
+                // fall through
+            }
+            final char[] ch = _currToken.asCharArray();
+            if (ch != null) {
+                return ch.length;
             }
         }
         return 0;
@@ -1495,13 +1522,10 @@ public class ProtobufParser extends ParserMinimalBase
     public boolean isNaN() {
         if (_currToken == JsonToken.VALUE_NUMBER_FLOAT) {
             if ((_numTypesValid & NR_DOUBLE) != 0) {
-                // 10-Mar-2017, tatu: Alas, `Double.isFinite(d)` only added in JDK 8
-                double d = _numberDouble;
-                return Double.isNaN(d) || Double.isInfinite(d);
+                return !Double.isFinite(_numberDouble);
             }
             if ((_numTypesValid & NR_FLOAT) != 0) {
-                float f = _numberFloat;
-                return Float.isNaN(f) || Float.isInfinite(f);
+                return !Float.isFinite(_numberFloat);
             }
         }
         return false;
@@ -1554,12 +1578,12 @@ public class ProtobufParser extends ParserMinimalBase
             _checkNumericValue(NR_UNKNOWN); // will also check event type
         }
         if (_currToken == JsonToken.VALUE_NUMBER_INT) {
-            if ((_numTypesValid & NR_INT) != 0) {
-                return NumberType.INT;
-            }
             if ((_numTypesValid & NR_LONG) != 0) {
                 return NumberType.LONG;
             }
+            if ((_numTypesValid & NR_INT) != 0) {
+                return NumberType.INT;
+            }
             return NumberType.BIG_INTEGER;
         }
 
@@ -1578,6 +1602,23 @@ public class ProtobufParser extends ParserMinimalBase
         return NumberType.FLOAT;
     }
 
+    @Override // since 2.17
+    public NumberTypeFP getNumberTypeFP() throws IOException
+    {
+        if (_currToken == JsonToken.VALUE_NUMBER_FLOAT) {
+            if ((_numTypesValid & NR_BIGDECIMAL) != 0) {
+                return NumberTypeFP.BIG_DECIMAL;
+            }
+            if ((_numTypesValid & NR_DOUBLE) != 0) {
+                return NumberTypeFP.DOUBLE64;
+            }
+            if ((_numTypesValid & NR_FLOAT) != 0) {
+                return NumberTypeFP.FLOAT32;
+            }
+        }
+        return NumberTypeFP.UNKNOWN;
+    }
+
     @Override
     public int getIntValue() throws IOException
     {
@@ -1995,7 +2036,7 @@ public class ProtobufParser extends ParserMinimalBase
                 break;
             default:
                 // Is this good enough error message?
-                _reportInvalidChar(c);
+                _reportInvalidInitial(c);
             }
             // Need more room?
             if (outPtr >= outEnd) {
@@ -2556,12 +2597,4 @@ public class ProtobufParser extends ParserMinimalBase
         _inputPtr = ptr;
         _reportInvalidOther(mask);
     }
-
-    private void _reportInvalidChar(int c) throws JsonParseException {
-        // Either invalid WS or illegal UTF-8 start char
-        if (c < ' ') {
-            _throwInvalidSpace(c);
-        }
-        _reportInvalidInitial(c);
-    }
 }
