@@ -28,11 +28,11 @@ public class BasicParserTest extends BaseTestForSmile
         // and then test passing one
         SmileParser p = _smileParser(data, false);
         assertToken(JsonToken.START_ARRAY, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.VALUE_NULL, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.END_ARRAY, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertNull(p.nextToken());
         p.close();
     }
@@ -54,17 +54,17 @@ public class BasicParserTest extends BaseTestForSmile
         SmileParser p = _smileParser(in, true);
 
         assertNull(p.getCurrentToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.START_ARRAY, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.VALUE_TRUE, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.VALUE_NULL, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.VALUE_FALSE, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.END_ARRAY, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertNull(p.nextToken());
         p.close();
     }
@@ -74,12 +74,12 @@ public class BasicParserTest extends BaseTestForSmile
         byte[] data = _smileDoc("[ 25.0 ]");
         SmileParser p = _smileParser(data);
         assertNull(p.getCurrentToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         assertToken(JsonToken.START_ARRAY, p.nextToken());
         assertToken(JsonToken.VALUE_NUMBER_FLOAT, p.nextToken());
         assertEquals(25, p.getIntValue());
         assertToken(JsonToken.END_ARRAY, p.nextToken());
-        assertNull(p.getCurrentName());
+        assertNull(p.currentName());
         p.close();
     }
 
@@ -110,7 +110,7 @@ public class BasicParserTest extends BaseTestForSmile
         assertNull(p.getCurrentToken());
         assertToken(JsonToken.START_OBJECT, p.nextToken());
         assertToken(JsonToken.FIELD_NAME, p.nextToken());
-        assertEquals("", p.getCurrentName());
+        assertEquals("", p.currentName());
 
         StringWriter w = new StringWriter();
         assertEquals(0, p.getText(w));
@@ -127,7 +127,7 @@ public class BasicParserTest extends BaseTestForSmile
         assertNull(p.getCurrentToken());
         assertToken(JsonToken.START_OBJECT, p.nextToken());
         assertToken(JsonToken.FIELD_NAME, p.nextToken());
-        assertEquals("abc", p.getCurrentName());
+        assertEquals("abc", p.currentName());
         assertToken(JsonToken.VALUE_STRING, p.nextToken());
         assertEquals("", p.getText());
         assertToken(JsonToken.END_OBJECT, p.nextToken());
@@ -140,11 +140,11 @@ public class BasicParserTest extends BaseTestForSmile
         assertNull(p.getCurrentToken());
         assertToken(JsonToken.START_OBJECT, p.nextToken());
         assertToken(JsonToken.FIELD_NAME, p.nextToken());
-        assertEquals("", p.getCurrentName());
+        assertEquals("", p.currentName());
         assertToken(JsonToken.VALUE_STRING, p.nextToken());
         assertEquals("", p.getText());
         assertToken(JsonToken.FIELD_NAME, p.nextToken());
-        assertEquals("", p.getCurrentName());
+        assertEquals("", p.currentName());
         assertToken(JsonToken.VALUE_STRING, p.nextToken());
         assertEquals("", p.getText());
         assertToken(JsonToken.END_OBJECT, p.nextToken());
@@ -215,7 +215,7 @@ public class BasicParserTest extends BaseTestForSmile
 
         assertToken(JsonToken.START_OBJECT, p.nextToken());
         assertToken(JsonToken.FIELD_NAME, p.nextToken());
-        assertEquals("abc", p.getCurrentName());
+        assertEquals("abc", p.currentName());
         assertEquals("abc", p.getText());
         assertToken(JsonToken.VALUE_NUMBER_INT, p.nextToken());
         assertEquals(13, p.getIntValue());
@@ -231,28 +231,28 @@ public class BasicParserTest extends BaseTestForSmile
     	assertToken(JsonToken.START_OBJECT, p.nextToken());
 
     	assertToken(JsonToken.FIELD_NAME, p.nextToken());
-    	assertEquals("a", p.getCurrentName());
+    	assertEquals("a", p.currentName());
     	assertEquals("a", p.getText());
     	assertToken(JsonToken.VALUE_NUMBER_INT, p.nextToken());
     	assertEquals(8, p.getIntValue());
 
     	assertToken(JsonToken.FIELD_NAME, p.nextToken());
-    	assertEquals("b", p.getCurrentName());
+    	assertEquals("b", p.currentName());
     	assertToken(JsonToken.START_ARRAY, p.nextToken());
     	assertToken(JsonToken.VALUE_TRUE, p.nextToken());
     	assertToken(JsonToken.END_ARRAY, p.nextToken());
 
     	assertToken(JsonToken.FIELD_NAME, p.nextToken());
-    	assertEquals("c", p.getCurrentName());
+    	assertEquals("c", p.currentName());
     	assertToken(JsonToken.START_OBJECT, p.nextToken());
     	assertToken(JsonToken.END_OBJECT, p.nextToken());
 
     	assertToken(JsonToken.FIELD_NAME, p.nextToken());
-    	assertEquals("d", p.getCurrentName());
+    	assertEquals("d", p.currentName());
 
     	assertToken(JsonToken.START_OBJECT, p.nextToken());
     	assertToken(JsonToken.FIELD_NAME, p.nextToken());
-    	assertEquals("e", p.getCurrentName());
+    	assertEquals("e", p.currentName());
     	assertToken(JsonToken.VALUE_NULL, p.nextToken());
     	assertToken(JsonToken.END_OBJECT, p.nextToken());
 
@@ -268,12 +268,12 @@ public class BasicParserTest extends BaseTestForSmile
         assertToken(JsonToken.START_ARRAY, p.nextToken());
         assertToken(JsonToken.START_OBJECT, p.nextToken());
         assertToken(JsonToken.FIELD_NAME, p.nextToken()); // a
-        assertEquals("a", p.getCurrentName());
+        assertEquals("a", p.currentName());
         assertToken(JsonToken.START_OBJECT, p.nextToken());
         assertToken(JsonToken.FIELD_NAME, p.nextToken()); // b
-        assertEquals("b", p.getCurrentName());
+        assertEquals("b", p.currentName());
         assertToken(JsonToken.START_ARRAY, p.nextToken());
-        assertEquals("b", p.getCurrentName());
+        assertEquals("b", p.currentName());
         assertToken(JsonToken.VALUE_NUMBER_INT, p.nextToken());
         assertToken(JsonToken.END_ARRAY, p.nextToken());
         assertToken(JsonToken.END_OBJECT, p.nextToken());
@@ -354,7 +354,7 @@ public class BasicParserTest extends BaseTestForSmile
         p = _smileParser(data);
         assertToken(JsonToken.START_OBJECT, p.nextToken());
         assertToken(JsonToken.FIELD_NAME, p.nextToken());
-        assertEquals(uc, p.getCurrentName());
+        assertEquals(uc, p.currentName());
         assertToken(JsonToken.VALUE_TRUE, p.nextToken());
         assertToken(JsonToken.END_OBJECT, p.nextToken());
         assertNull(p.nextToken());
@@ -418,7 +418,7 @@ public class BasicParserTest extends BaseTestForSmile
             while (i < count) {
                 assertToken(JsonToken.START_OBJECT, p.nextToken());
                 assertToken(JsonToken.FIELD_NAME, p.nextToken());
-                assertEquals(FIELD, p.getCurrentName());
+                assertEquals(FIELD, p.currentName());
                 assertToken(JsonToken.VALUE_NUMBER_INT, p.nextToken());
                 assertEquals((i % 17), p.getIntValue());
                 assertToken(JsonToken.END_OBJECT, p.nextToken());
@@ -638,7 +638,7 @@ public class BasicParserTest extends BaseTestForSmile
         throws IOException
     {
         assertEquals(expName, p.getText());
-        assertEquals(expName, p.getCurrentName());
+        assertEquals(expName, p.currentName());
     }
 
     protected void verifyIntValue(JsonParser p, long expValue)
